@@ -29,7 +29,7 @@ def main():
 
     for path in sorted(root_path.rglob('*')):
         first_dir = path.relative_to(root_path).parts [0]
-        if first_dir == '.git' or first_dir == '.ipynb_checkpoints' or path.suffix == '.sh':
+        if first_dir == '.git' or first_dir == '.ipynb_checkpoints' or path.suffix == '.sh' or first_dir == "__pycache__":
             continue
         if path.is_dir():
             output_path_dir = output_path_root/ Path(*[p if p!='recoform' else package_name for p in path.relative_to(root_path).parts])
